.. highlight:: python


=====
Raven
=====

Note: this section is not yet implemented, but document as if it were as part of DDD.

Talisker configures the generic raven WSGI middleware to catch exceptions, and
adds the request id into the data collected.

